==> igniteui-react-16.16.2.tgz: package/esm5/lib/Snackbar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Snackbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Snackbar, _super);
    function Snackbar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.g = null;
        _this.action = null;
        return _this;
    }
    Object.defineProperty(Snackbar.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.b.d = this.g;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "e", {
        get: function () {
            var ret_ = this.c.c("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "f", {
        get: function () {
            var ret_ = this.c.c("displayTime");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("displayTime", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "d", {
        get: function () {
            var ret_ = this.c.c("keepOpen");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("keepOpen", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "i", {
        get: function () {
            var ret_ = this.c.c("actionText");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("actionText", value_);
        },
        enumerable: false,
        configurable: true
    });
    Snackbar.prototype.actionChanged = function () {
        var _this = this;
        if (this.action != null) {
            this.c.g("action", function (a) { return _this.action(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.c.h("action");
        }
    };
    Snackbar.prototype.l = function () {
        this.nativeElement.show();
    };
    Snackbar.prototype.k = function () {
        this.nativeElement.hide();
    };
    Snackbar.prototype.m = function () {
        this.nativeElement.toggle();
    };
    Snackbar.$t = markType(Snackbar, 'Snackbar', BaseElement.$);
    return Snackbar;
}(BaseElement));
export { Snackbar };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Snackbar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Snackbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Snackbar, _super);
    function Snackbar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.g = null;
        _this.action = null;
        return _this;
    }
    Object.defineProperty(Snackbar.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.b.o = this.g;
        },
        enumerable: false,
        configurable: true
    });
    Snackbar.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Snackbar.prototype, "e", {
        get: function () {
            var ret_ = this.c.n("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "f", {
        get: function () {
            var ret_ = this.c.n("displayTime");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("displayTime", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "d", {
        get: function () {
            var ret_ = this.c.n("keepOpen");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("keepOpen", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Snackbar.prototype, "i", {
        get: function () {
            var ret_ = this.c.n("actionText");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("actionText", value_);
        },
        enumerable: false,
        configurable: true
    });
    Snackbar.prototype.actionChanged = function () {
        var _this = this;
        if (this.action != null) {
            this.c.r("action", function (a) { return _this.action(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.c.u("action");
        }
    };
    Snackbar.prototype.m = function () {
        this.nativeElement.show();
    };
    Snackbar.prototype.k = function () {
        this.nativeElement.hide();
    };
    Snackbar.prototype.n = function () {
        this.nativeElement.toggle();
    };
    Snackbar.$t = markType(Snackbar, 'Snackbar', BaseElement.$);
    return Snackbar;
}(BaseElement));
export { Snackbar };
